//
// JavaScript specific to figures and multi-media objects
//

/**
 * Carry out any processing required on AJAX data received
 *
 * @param {string}  dialogName
 * @param {integer} dialogHeight
 * @param {integer} dialogWidth
 * @param {string}  mimeType
 * @param {string}  videoUrl
 */
function postProcessing(dialogName, dialogHeight, dialogWidth, mimeType, videoUrl) {
    //
    //if (consoleOK) {console.info("postProcessing() parameters:\n\n" +
    //                    "1. dialogName: " + dialogName.attr("id") + "\n" +
    //                    "2. dialogHeight: " + dialogHeight + "\n" +
    //                    "3. dialogWidth: " + dialogWidth + "\n" +
    //                    "4. mimeType: " + mimeType + "\n" +
    //                    "5. videoUrl: " + videoUrl + "\n");}
    //
    var dialogType = dialogName.attr("id");
    switch (dialogType) {
    case "figuredialog":
        break;
    case "tabledialog":
        break;
    case "videodialog":
        if (videoUrl !== "") {
            jwplayer("videodialog").setup({
                file: videoUrl,
                fallback: false
            });
        } else {
            alert("No video source details available...");
        }
        break;
    default:
        break;
    }
}

// Function to call AJAX
/**
 *
 * @param {object} here            Here we are!
 * @param {object} dialogName      Dialog to be used
 * @param {string} url             Target for AJAX call
 * @param {string} dialogTitle
 * @param {string} citation        Citation string
 * @param {string} container       High(er)-level container block
 * @param {string} additionalText  Any additional text required for display
 *
 */
function processAjax(here, dialogName, url, dialogTitle, citation, container, additionalText) {
    //
    //if (consoleOK) {console.info("processAjax() parameters:\n\n" +
    //                    "1. here: Here" + "\n" +
    //                    "2. dialogName: " + dialogName + "\n" +
    //                    "3. url: " + url + "\n" +
    //                    "4. dialogTitle: " + dialogTitle + "\n" +
    //                    "5. citation: " + citation + "\n" +
    //                    "6. container: " + container + "\n" +
    //                    "7. additionalText: " + additionalText + "\n");}
    //
    // Set up the dialog window size...
    var dialogWidth = $(window).width() * 0.6,      // Default width...
        dialogHeight = $(window).height() * 0.8,    // Default height...
        mimeType = "",
        videoUrl = "";
    // Use the dialog id to determine the type...
    if (dialogName.attr("id") === "videodialog") {
        dialogHeight = "auto";
        dialogWidth = "auto";
    }
    // Make the call...
    $.ajax({
        type: "GET",
        url: url,
        datatype: "html",
        success: function(resp, statusText) {
            // Add the response to our DOM without accidentally stripping out any MathML
            dialogName.get(0).innerHTML = resp;
            // Find the contents we're interested in
            var multimediaElement = $(".multimediaContainer", dialogName).get(0);
            // Make sure our dialog only contains that bit
            dialogName.get(0).innerHTML = "<" + multimediaElement.tagName + " id=\"" + multimediaElement.id + "\" class=\"" +
                multimediaElement.getAttribute("class") + "\">" + multimediaElement.innerHTML + "</" + multimediaElement.tagName + ">";
            var dialogContent = $(".multimediaContainer", dialogName);
            if (dialogContent.length > 0) {
                // Grab the url and mime type for the video...
                mimeType = $(".mediaFormatType", dialogName).text();
                videoUrl = $(".mediaSource", dialogName).text();
                // Set the width and height as a proportion of the current viewport size
                dialogName.dialog({
                    title: dialogTitle,
                    height: dialogHeight,
                    width: dialogWidth
                });
                MathJax.Hub.Queue(["Typeset", MathJax.Hub, dialogName.get(0)]);
                // Just grab the first such link. When logged in as admin there are more...
                dialogName.find(".dialogCitation span:first").after(citation);
                if (additionalText !== "") {
                    dialogName.append("<span class=\"additionalText\">" + additionalText + "</span>");
                }
                dialogName.dialog("open");
                postProcessing(dialogName, dialogHeight, dialogWidth, mimeType, videoUrl);
            } else {
                alert("No contents returned...");
            }

        },
        error: function(req, statusText) {
            alert("The attempt to retrieve the full size version of this object has failed.");
        },
        complete: function(req, statusText) {
            here.addClass("cursorPointer").removeClass("cursorWait");
            here.closest(container).removeClass("cursorWait opened");
        }
    });
}

$(document).ready(function() {

    var hiddenContext = $("#hiddenContext").text();

    // Identify the dialog "hooks"...
    var figureDialog     = $("#figuredialog"),
        tableDialog      = $("#tabledialog"),
        videoDialog      = $("#videodialog"),
        multimediaDialog = $("#multimediadialog");

    // Declare some default dialog attributes
    var stdDialogOptions = {
            autoOpen: false,
            modal: true,
            resizable: true,
            position: {
                my: "center",
                at: "center",
                of: $(window)
            }
    };

    // Create the dialog boxes...
    figureDialog.dialog(stdDialogOptions);
    tableDialog.dialog(stdDialogOptions);
    videoDialog.dialog(stdDialogOptions);
    multimediaDialog.dialog(stdDialogOptions);

    // Remove contents as the dialog is closed
    figureDialog.bind("dialogbeforeclose", function(event) {
        figureDialog.find(".multimediaContainer").remove();
        figureDialog.find(".dialogCitation").remove();
    });

    tableDialog.bind("dialogbeforeclose", function(event) {
        tableDialog.find(".multimediaContainer").remove();
        tableDialog.find(".dialogCitation").remove();
    });

    videoDialog.bind("dialogbeforeclose", function(event) {
        videoDialog.find(".multimediaContainer").remove();
        videoDialog.find(".dialogCitation").remove();
    });

    multimediaDialog.bind("dialogbeforeclose", function(event) {
        multimediaDialog.find(".multimediaContainer").remove();
        multimediaDialog.find(".dialogCitation").remove();
    });

    // Define some messages
    var MSG_NO_FIGURE_URL = "No location specified from which to retrieve figure image...",
        MSG_NO_TABLE_URL  = "No location specified from which to retrieve table...",
        MSG_NO_VIDEO_URL  = "No location specified from which to retrieve multimedia object...",
        MSG_VIDEO_TEXT    = 'This video can only be played using <a href="http://get.adobe.com/flashplayer/">Flash Player</a>.';

    // Process request for figure from Fulltext tab...
    $("#html-body .figure .image a").live("click", function(e) {
        // Keep a record of where we are...
        var here = $(this);
        var container = "#html-body",
            semaphore = here.closest(container);
        // Stop any link action...
        e.preventDefault();
        // Use a class as a semaphore...
        if (!semaphore.hasClass("opened")) {
            semaphore.addClass("opened").addClass("cursorWait");
            here.removeClass("cursorPointer").addClass("cursorWait");
            var itemMetadata = here.parents(".articlefulltext").find(".hiddenjsdiv.itemmetadata");
            var citation = itemMetadata.find(".metadata_citation").html();
            var mediaMetadata = here.parents(".figure");
            var dialogTitle  = mediaMetadata.find(".caption .captionLabel .label").text();
            var url = hiddenContext + mediaMetadata.find(".image a").attr("id");

            if (url !== "") {
                processAjax(here, multimediaDialog, url, dialogTitle, citation, container, "");
            } else {
                alert(MSG_NO_FIGURE_URL);
            }
            return false;
        }
    });

    // Process request for table from Fulltext tab...
    $("#html-body .table .image a").live("click", function(e) {
        // Keep a record of where we are...
        var here = $(this);
        var container = "#html-body",
            semaphore = here.closest(container);
        // Stop any link action...
        e.preventDefault();
        // Use a class as a semaphore...
        if (!semaphore.hasClass("opened")) {
            semaphore.addClass("opened").addClass("cursorWait");
            here.removeClass("cursorPointer").addClass("cursorWait");
            var itemMetadata = here.parents(".articlefulltext").find(".hiddenjsdiv.itemmetadata");
            var citation = itemMetadata.find(".metadata_citation").html();
            var mediaMetadata = here.parents(".table");
            var dialogTitle  = mediaMetadata.find(".caption .captionLabel .label").text();
            var url = hiddenContext + mediaMetadata.find(".image a").attr("id");

            if (url !== "") {
                processAjax(here, multimediaDialog, url, dialogTitle, citation, "");
            } else {
                alert(MSG_NO_TABLE_URL);
            }
            return false;
        }
    });

    // Process request for multimedia object from Fulltext tab...
    $("#html-body a.media-link span").live("click", function(e) {
        // Keep a record of where we are...
        var here = $(this);
        var container = "#html-body",
            semaphore = here.closest(container);
        // Stop any link action...
        e.preventDefault();
        // Use a class as a semaphore...
        if (!semaphore.hasClass("opened")) {
            semaphore.addClass("opened").addClass("cursorWait");
            here.removeClass("cursorPointer").addClass("cursorWait");
            var itemMetadata = here.parents(".articlefulltext").find(".hiddenjsdiv.itemmetadata");
            var citation = itemMetadata.find(".metadata_citation").html();
            var mediaMetadata = "";
            var dialogTitle  = "Multimedia object";
            var url = hiddenContext + "/content/multimedia/" + here.text();

            if (url !== "") {
                processAjax(here, videoDialog, url, dialogTitle, citation, MSG_VIDEO_TEXT);
            } else {
                alert(MSG_NO_VIDEO_URL);
            }
            return false;
        }
    });

    // Process request for figure from Data and Media tab...
    $(".figureSmallImageContainer img.showFullVersion, .figureSmallImageContainer p.click2view").live("click", function() {
        // Keep a record of where we are...
        var here = $(this);
        var container = ".figuresblock",
            semaphore = here.closest(container);
        // Use a class as a semaphore...
        if (!semaphore.hasClass("opened")) {
            semaphore.addClass("opened").addClass("cursorWait");
            here.removeClass("cursorPointer").addClass("cursorWait");
            var itemMetadata = here.parents(".dataandmedia").find(".hiddenjsdiv.itemmetadata");
            var citation = itemMetadata.find(".metadata_citation").html();
            var figMetadata = here.parents(".singleFigureContainer").find(".hiddenjsdiv.mediametadata");
            var dialogTitle  = figMetadata.find(".metadata_title").text();
            var url = hiddenContext + figMetadata.find(".metadata_webId").text();

            if (url !== "") {
                processAjax(here, figureDialog, url, dialogTitle, citation, container, "");
            } else {
                alert(MSG_NO_FIGURE_URL);
            }
            return false;
        }
    });

    // Process request for table...
    $(".tableSmallImageContainer img.showFullVersion, .tableSmallImageContainer p.click2view").live("click", function() {
        // Keep a record of where we are...
        var here = $(this);
        var container = ".tablesblock",
            semaphore = here.closest(container);
        // Use a class as a semaphore...
        if (!semaphore.hasClass("opened")) {
            semaphore.addClass("opened").addClass("cursorWait");
            here.removeClass("cursorPointer").addClass("cursorWait");
            var itemMetadata = here.parents(".dataandmedia").find(".hiddenjsdiv.itemmetadata");
            var citation = itemMetadata.find(".metadata_citation").html();
            var tabMetadata = here.parents(".singleTableContainer").find(".hiddenjsdiv.mediametadata");
            var dialogTitle  = tabMetadata.find(".metadata_title").text();
            var url = hiddenContext + tabMetadata.find(".metadata_webId").text();

            if (url !== "") {
                processAjax(here, tableDialog, url, dialogTitle, citation, container, "");
            } else {
                alert(MSG_NO_TABLE_URL);
            }
            return false;
        }
    });

    // Process request for video...
    $(".multimediaSmallImageContainer img.showFullVersion, .multimediaSmallImageContainer p.click2view").live("click", function(){
        // Keep a record of where we are...
        var here = $(this);
        var container = ".multimediablock",
            semaphore = here.closest(container);
        // Use a class as a semaphore...
        if (!semaphore.hasClass("opened")) {
            semaphore.addClass("opened").addClass("cursorWait");
            here.removeClass("cursorPointer").addClass("cursorWait");
            var itemMetadata = here.parents(".dataandmedia").find(".hiddenjsdiv.itemmetadata");
            var citation = itemMetadata.find(".metadata_citation").html();
            var vidMetadata = here.parents(".singleMultimediaContainer").find(".hiddenjsdiv.mediametadata");
            var dialogTitle  = "Multimedia object - " + vidMetadata.find(".metadata_title").text();
            var url = hiddenContext + vidMetadata.find(".metadata_webId").text();

            if (url !== "") {
                processAjax(here, videoDialog, url, dialogTitle, citation, container, MSG_VIDEO_TEXT);
            } else {
                alert(MSG_NO_VIDEO_URL);
            }
            return false;
        }
    });
    
    // Submit 'download as PPT' form from text link
    $(".downloadPpt").live("click", function(e) {
        var pptForm = $(this).closest("form");
        pptForm.submit();
    });

});
